#
# spec file for package gfs2-utils
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gfs2-utils
Version:        3.5.1
Release:        150600.1.5
Summary:        Utilities for managing the global file system (GFS2)
License:        GPL-2.0-or-later AND LGPL-2.0-or-later
Group:          System/Filesystems
URL:            https://pagure.io/gfs2-utils
Source:         https://pagure.io/gfs2-utils/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  bzip2
BuildRequires:  check
BuildRequires:  flex
BuildRequires:  gettext
BuildRequires:  libblkid-devel
BuildRequires:  libblkid1
BuildRequires:  libbz2-devel
BuildRequires:  libtool
BuildRequires:  libuuid-devel
BuildRequires:  libuuid1
BuildRequires:  make
BuildRequires:  ncurses-devel
BuildRequires:  zlib-devel

# Upstream patches
Patch1:         0001-fsck.gfs2-Tighten-offset-check-in-check_eattr_entrie.patch
Patch2:         0002-fsck.gfs2-Fix-max-xattr-record-length-check.patch
Patch3:         0003-fsck.gfs2-Fix-xattr-offset-checks-in-p1_check_eattr_.patch

%description
The gfs2-utils package contains a number of utilities for creating,
checking, modifying, and correcting any inconsistencies in GFS2
file systems.

%prep
%setup -q

%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
#NOCONFIGURE=1
./autogen.sh
%configure
%make_build

%check
make check

%install
make -C gfs2 install DESTDIR=%{buildroot}
# Don't ship gfs2_{trace,lockcapture} in this package
rm -f %{buildroot}%{_sbindir}/gfs2_trace
rm -f %{buildroot}%{_sbindir}/gfs2_lockcapture
rm -f %{buildroot}%{_mandir}/man8/gfs2_trace.8
rm -f %{buildroot}%{_mandir}/man8/gfs2_lockcapture.8

%files
%license doc/COPYING.*
%doc doc/COPYRIGHT doc/README.* doc/*.txt
%dir %{_prefix}/lib/udev
%dir %{_prefix}/lib/udev/rules.d
%{_sbindir}/fsck.gfs2
%{_sbindir}/glocktop
%{_sbindir}/mkfs.gfs2
%{_sbindir}/tunegfs2
%{_sbindir}/gfs2_*
%{_libexecdir}/gfs2_withdraw_helper
%{_prefix}/lib/udev/rules.d/82-gfs2-withdraw.rules
%{_mandir}/man8/*gfs2*%{?ext_man}
%{_mandir}/man5/*
%{_mandir}/man8/glocktop.8%{?ext_man}

%changelog
* Mon Aug 21 2023 heming.zhao@suse.com
- Update to version 3.5.1 (jsc#PED-6362)
  * Don't use char arrays as temporary buffers
  * libgfs2: Separate gfs and gfs2 code in lgfs2_sb_out()
  * Re-enable -Wstrict-aliasing
  * gfs2_convert: Clean up strict-aliasing warnings
  * libgfs2: Fix strict-aliasing warning in lgfs2_rgrp_bitbuf_alloc
  * gfs2_jadd: Fix format string warnings on 32-bit
  * gfs2_edit: Fix savemeta test failures in 32-bit environments
- Back port bugfix patch after tag 3.5.1
  + 0001-fsck.gfs2-Tighten-offset-check-in-check_eattr_entrie.patch
  + 0002-fsck.gfs2-Fix-max-xattr-record-length-check.patch
  + 0003-fsck.gfs2-Fix-xattr-offset-checks-in-p1_check_eattr_.patch
- Update rpm build file
  * _service
  * _servicedata
* Mon Mar  6 2023 andrea.manzini@suse.com
- Update to version 3.5.0:
  * Update translation template
  * Fix uninitialized memory coverity warnings
  * gfs2_grow: Don't free rgs when it's NULL
  * libgfs2: Fix potential NULL deref in lgfs2_lookupi()
  * libgfs2: Add lgfs2_bfree(), lgfs2_inode_free()
  * Free per_node in build_per_node error paths
  * fsck.gfs2: Fix wrong entry used in dentry comparison
  * added unit tests
  * Remove lgfs2_breadm()
  * libgfs2: Make sure block_alloc() fails when out of space
  * Remove dependency on linux/limits.h
  * mkfs.gfs2: Improve journal write error reporting
  * mkfs.gfs2: Add -U UUID option
* Wed Nov 24 2021 varkoly@suse.com
- Update to version 3.4.1+git.87.c0ea1bc4:
  * libgfs2: Remove new_rgrps from struct gfs2_sbd
  * tests: Increase the size of the sparse file used by tests
  * gfs2/edit: always use "%%s"-style format for printf()-style functions
  * tunegfs2: Use O_EXCL when opening the device rw
  * Make sure i_bh is set after lgfs2_gfs_inode_get()
  * libgfs2: Avoid potential gfs/gfs2 superblock update clash
  * gfs2_edit: Fix segfault in hexdump()
  * libgfs2: Add NULL-checking for ip->i_bh in inode_put()
  * fsck.gfs2: Fix remaining endianness sparse warnings
  * gfs2_edit: Fix remaining endianness sparse warnings
* Wed Aug  3 2016 zren@suse.com
- Update to version 3.1.9
- Fix RPM building error due to upstream putting all binaries
  into /usr/sbin now
* Wed Jan 14 2015 p.drouand@gmail.com
- Update to version 3.1.7
  + No changelog available
- Use download Url as source
- Use official tarball
- Specfile cleanup
- Pass NOCONFIGURE to autogen.sh
* Tue Sep 17 2013 lmb@suse.com
- Update spec file copyright
- Remove unnecessary clean section
* Fri Sep 13 2013 lmb@suse.com
- Update to 3.1.6+git.1378394292.fa32906
- Remove source URL from spec file, since there are no downloadable tar
  balls for the git version
* Sat Aug  3 2013 rgoldwyn@suse.com
- Initial package gfs2-utils
